@@ -45,6 +45,8 @@ class Controller(object):
 
     def select_folder_dialog(self):
         select_path = cmds.fileDialog2(dialogStyle=2, fileMode=3)[0]
+        if not select_path:
+            return
         self.gui.ui.PathLineEdit.setText(select_path)
 
     def start_monitor(self):
@@ -138,14 +140,5 @@ class GUILogHandler(logging.Handler):
         else:
             msg = ""
 
-        # self.createLock()
-
-        # self.acquire()
-
         maya.utils.executeInMainThreadWithResult(partial(self.plain_text_edit.verticalScrollBar().setValue, self.plain_text_edit.verticalScrollBar().maximum()))
         maya.utils.executeInMainThreadWithResult(partial(self.plain_text_edit.appendPlainText, msg))
-        # self.plain_text_edit.appendPlainText(msg)
-        # self.plain_text_edit.verticalScrollBar().setValue(self.plain_text_edit.verticalScrollBar().maximum())
-        # self.plain_text_edit.update()
-
-        # self.release()
